# chloro - personal space
# Copyright (C) 2019  Frederic Peters
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from functools import partial

import ckeditor.views as ckeditor_views
from django.conf.urls import url
from django.contrib.admin.views.decorators import staff_member_required
from django.views.decorators.cache import never_cache

from . import views

staff_required = partial(staff_member_required, login_url='login')


urlpatterns = [
    url(
        r'^ckeditor/upload/',
        staff_required(ckeditor_views.upload),
        name='ckeditor_upload',
    ),
    url(
        r'^ckeditor/browse/',
        never_cache(staff_required(ckeditor_views.browse)),
        name='ckeditor_browse',
    ),
    url(r'^(?P<slug>[\w:-]+)/edit/$', staff_required(views.NoteEditView.as_view())),
    url(
        r'^(?P<slug>[\w:-]+)/delete/$',
        staff_required(views.NoteDeleteView.as_view()),
    ),
    url(r'^(?P<slug>[\w:-]+)/api-save/$', staff_required(views.NoteApiSaveView.as_view())),
    url(r'^ajax/upload/$', staff_required(views.ajax_upload)),
    url(r'^ajax/newpage/$', staff_required(views.ajax_new_page)),
    url(r'^ajax/search/$', views.ajax_search, name='ajax-search'),
    url(r'^new-note/$', staff_required(views.NoteAddView.as_view())),
    url(r'^feeds/(?P<sub>[\w:-]+)/atom$', views.AtomFeed()),
    url(r'^feed/atom$', views.AtomFeed()),
    url(r'^tag/(?P<tag>[\w:-]+)/$', views.ListOnTagView.as_view()),
    url(r'^archives/$', views.ArchivesView.as_view()),
    url(r'^(?P<year>\d{4})/(?P<month>\d{2})/(?P<day>\d{2})/(?P<slug>[\w:-]+)/$', views.NoteView.as_view()),
    url(r'^(?P<slug>[\w:-]+)/$', views.NoteView.as_view()),
    url(r'^$', views.HomeView.as_view()),
]
